@@ -138,7 +138,7 @@ def is_edited_version_of_file(file1: pathlib.Path, file2: pathlib.Path) -> bool:
     """Return True if file2 appears to be an edited version of file1"""
     if match := re.match(ORIGINAL_RE, str(file1)):
         if re.match(
-            f"{match.group(1)}{match.group(2)}_E{match.group(3)}{match.group(4)}",
+            f"{re.escape(match.group(1))}{match.group(2)}_E{match.group(3)}{re.escape(match.group(4))}",
             str(file2),
         ):
             return True
